@@ -2,7 +2,10 @@ use scion::{
     core::{
         components::maths::transform::Transform,
         resources::{
-            inputs::{inputs_controller::InputsController, keycode::KeyCode, InputState},
+            inputs::{
+                inputs_controller::InputsController,
+                types::{KeyCode},
+            },
             time::{TimerType, Timers},
         },
     },
@@ -19,20 +22,14 @@ pub fn move_char(
     query: &mut Query<(&mut Hero, &mut Transform)>,
 ) {
     if !timers.exists("input") {
-        timers.add_timer("input", TimerType::Manual, 0.05);
+        let _r = timers.add_timer("input", TimerType::Manual, 0.05);
     }
     if !timers.exists("gravity") {
-        timers.add_timer("gravity", TimerType::Manual, 0.005);
+        let _r = timers.add_timer("gravity", TimerType::Manual, 0.005);
     }
 
     let input_velocity = read_velocity(inputs);
-    let jump = inputs
-        .keyboard()
-        .keyboard_events()
-        .iter()
-        .filter(|e| e.state.eq(&InputState::Pressed) && e.keycode.eq(&KeyCode::Up))
-        .count()
-        > 0;
+    let jump = inputs.key_pressed(&KeyCode::Up);
 
     if input_velocity != 0 {
         let timer = timers.get_timer("input").expect("Missing timer : input");
@@ -71,9 +68,7 @@ pub fn move_char(
             }
         });
     } else {
-        let timer = timers
-            .get_timer("gravity")
-            .expect("Missing timer : gravity");
+        let timer = timers.get_timer("gravity").expect("Missing timer : gravity");
         query.for_each_mut(world, |(hero, _t)| {
             if !hero.landed {
                 if timer.ended() {
@@ -89,13 +84,13 @@ pub fn move_char(
 
 fn read_velocity(inputs: &InputsController) -> i32 {
     ({
-        if inputs.keyboard().key_pressed(&KeyCode::Left) {
+        if inputs.key_pressed(&KeyCode::Left) {
             -1
         } else {
             0
         }
     }) + ({
-        if inputs.keyboard().key_pressed(&KeyCode::Right) {
+        if inputs.key_pressed(&KeyCode::Right) {
             1
         } else {
             0
