@@ -17,16 +17,14 @@ pub(crate) fn collider(
     transform: &Transform,
 ) {
     if let Material::Color(_c) = material {
-        collider.collisions().for_each(|collision| {
-            match collision.mask() {
-                ColliderMask::Death => std::process::exit(0),
-                ColliderMask::Landscape => {
-                    if collision.coordinates().y() > transform.global_translation().y() {
-                        hero.landed = true;
-                    }
+        collider.collisions().iter().for_each(|collision| match collision.mask() {
+            ColliderMask::Death => std::process::exit(0),
+            ColliderMask::Landscape => {
+                if collision.coordinates().y() > transform.global_translation().y() {
+                    hero.landed = true;
                 }
-                _ => {}
             }
+            _ => {}
         });
     }
 }
