@@ -1,9 +1,12 @@
 mod character_control_system;
 mod collisions_system;
 
+
 use std::{path::Path, str::from_utf8};
 
 use legion::IntoQuery;
+
+
 use scion::{
     config::{scion_config::ScionConfigBuilder, window_config::WindowConfigBuilder},
     core::{
@@ -14,12 +17,12 @@ use scion::{
                 camera::Camera,
                 collider::{Collider, ColliderMask, ColliderType},
                 hierarchy::Parent,
-                transform::{Coordinates, Transform},
+                transform::Transform,
             },
             shapes::rectangle::Rectangle,
             Square,
         },
-        game_layer::{GameLayer, SimpleGameLayer},
+        scene::Scene,
     },
     legion::{Entity, Resources, World},
     utils::file::{app_base_path, read_file},
@@ -38,31 +41,29 @@ pub struct Hero {
 }
 
 #[derive(Default)]
-pub struct Mario {
+pub struct MainScene {
     hero: Option<Entity>,
     map: Vec<Vec<usize>>,
 }
 
-impl SimpleGameLayer for Mario {
+impl Scene for MainScene {
     fn on_start(&mut self, world: &mut World, _resources: &mut Resources) {
         add_background(world);
         self.hero = Some(add_character(world));
         self.map = add_level_data(world);
-        let mut camera_transform = Transform::new(Coordinates::new(-202., -320.), 1.0, 0.);
+        let mut camera_transform = Transform::from_xy(-202., -320.);
         camera_transform.set_global_translation_bounds(Some(0.), Some(2060.), Some(0.), Some(0.));
         world.push((
-            Camera::new(500., 640., 10.),
+            Camera::new(500., 640.),
             camera_transform,
             Parent(self.hero.expect("Hero is mandatory")),
         ));
     }
     fn late_update(&mut self, world: &mut World, _resources: &mut Resources) {
-        let hero = <(&mut Hero, &mut Transform)>::query()
-            .get_mut(world, self.hero.unwrap())
-            .unwrap();
+        let hero =
+            <(&mut Hero, &mut Transform)>::query().get_mut(world, self.hero.unwrap()).unwrap();
         if hero.0.velocity != 0 {
-            hero.1
-                .append_x(hero.0.velocity as f32 / MAX_VELOCITY as f32 * 2.5);
+            hero.1.append_x(hero.0.velocity as f32 / MAX_VELOCITY as f32 * 2.5);
         }
 
         if hero.0.gravity != 0 {
@@ -96,20 +97,16 @@ impl SimpleGameLayer for Mario {
 }
 
 fn add_level_data(world: &mut World) -> Vec<Vec<usize>> {
-    let file = read_file(Path::new(
-        &app_base_path()
-            .join("examples/mario/assets/level.csv")
-            .get(),
-    ))
-    .unwrap_or(vec![]);
+    let file = read_file(Path::new(&app_base_path().join("examples/mario/assets/level.csv").get()))
+        .unwrap_or_default();
     let csv = from_utf8(file.as_slice()).expect("no");
     let data: Vec<Vec<usize>> = csv
         .split("\r\n")
-        .map(|e| e.split(",").map(|f| f.parse::<usize>().unwrap()).collect())
+        .map(|e| e.split(',').map(|f| f.parse::<usize>().unwrap()).collect())
         .collect();
     for (i, line) in data.iter().enumerate() {
         for (j, val) in line.iter().enumerate() {
-            let t = Transform::new(Coordinates::new(j as f32 * 64., i as f32 * 64.), 1., 0.);
+            let t = Transform::from_xy(j as f32 * 64., i as f32 * 64.);
             match *val {
                 0 => {
                     world.push((
@@ -151,30 +148,22 @@ fn add_level_data(world: &mut World) -> Vec<Vec<usize>> {
 fn add_background(world: &mut World) {
     let background = (
         Rectangle::new(2560., 640., None),
-        Material::Texture(
-            app_base_path()
-                .join("examples/mario/assets/level.png")
-                .get(),
-        ),
-        Transform::new(Coordinates::new_with_layer(0., 0., 1), 1., 0.),
+        Material::Texture(app_base_path().join("examples/mario/assets/level.png").get()),
+        Transform::from_xyz(0., 0., 1),
     );
     world.push(background);
 }
 
 fn add_character(world: &mut World) -> Entity {
     world.push((
-        Hero {
-            velocity: 0,
-            gravity: 1,
-            landed: false,
-        },
+        Hero { velocity: 0, gravity: 1, landed: false },
         Collider::new(
             ColliderMask::Character,
             vec![ColliderMask::Landscape, ColliderMask::Death],
             ColliderType::Square(64),
         ),
         Square::new(64., None),
-        Transform::new(Coordinates::new_with_layer(256., 320., 2), 1., 0.),
+        Transform::from_xyz(256., 320., 2),
         Material::Color(Color::new_rgb(100, 120, 23)),
     ))
 }
@@ -182,15 +171,10 @@ fn add_character(world: &mut World) -> Entity {
 fn main() {
     Scion::app_with_config(
         ScionConfigBuilder::new()
-            .with_window_config(
-                WindowConfigBuilder::new()
-                    .with_dimensions((500, 640))
-                    .with_resizable(false)
-                    .get(),
-            )
+            .with_window_config(WindowConfigBuilder::new().with_dimensions((500, 640)).get())
             .get(),
     )
-    .with_game_layer(GameLayer::weak::<Mario>("Mario"))
+    .with_scene::<MainScene>()
     .with_system(move_char_system())
     .with_system(collider_system())
     .run();
