@@ -2,20 +2,19 @@ use scion::{
     config::{scion_config::ScionConfigBuilder, window_config::WindowConfigBuilder},
     core::{
         components::{
-            maths::{
-                camera::Camera,
-                transform::{Coordinates, Transform},
-            },
+            maths::{coordinates::Coordinates, transform::Transform},
             tiles::{sprite::Sprite, tileset::Tileset},
         },
-        game_layer::{GameLayer, SimpleGameLayer},
-        resources::{asset_manager::AssetManager, inputs::inputs_controller::InputsController},
+        legion_ext::{ScionResourcesExtension, ScionWorldExtension},
+        resources::inputs::inputs_controller::InputsController,
+        scene::Scene,
     },
     legion::{system, Resources, World},
     utils::file::app_base_path,
     Scion,
 };
 
+
 #[derive(Debug)]
 struct Case(Coordinates);
 
@@ -66,9 +65,7 @@ fn taquin(
     case: &mut Case,
     transform: &mut Transform,
 ) {
-    if inputs.mouse().click_event().is_some() {
-        let mouse_x = inputs.mouse().x();
-        let mouse_y = inputs.mouse().y();
+    inputs.on_left_click_pressed(|mouse_x, mouse_y| {
         if mouse_x > (case.0.x() * 192.) as f64
             && mouse_y > (case.0.y() * 192.) as f64
             && mouse_x < (case.0.x() * 192. + 192.) as f64
@@ -94,34 +91,25 @@ fn taquin(
                 MoveDirection::None => {}
             };
         }
-    }
+    })
 }
 
 #[derive(Default)]
-struct Layer;
+struct MainScene;
 
-impl SimpleGameLayer for Layer {
+impl Scene for MainScene {
     fn on_start(&mut self, world: &mut World, resources: &mut Resources) {
-        let tileset_ref = resources
-            .get_mut::<AssetManager>()
-            .expect("AssetManager is mandatory")
-            .register_tileset(Tileset::new(
-                app_base_path()
-                    .join("examples/taquin/assets/taquin.png")
-                    .get(),
-                4,
-                4,
-                192,
-            ));
+        let tileset_ref = resources.assets().register_tileset(Tileset::new(
+            app_base_path().join("examples/taquin/assets/taquin.png").get(),
+            4,
+            4,
+            192,
+        ));
         for line in 0..4 {
             for column in 0..4 {
                 if !(line == 3 && column == 3) {
                     let square = (
-                        Transform::new(
-                            Coordinates::new(column as f32 * 192., line as f32 * 192.),
-                            1.,
-                            0.,
-                        ),
+                        Transform::from_xy(column as f32 * 192., line as f32 * 192.),
                         tileset_ref.clone(),
                         Sprite::new(line * 4 + column),
                         Case(Coordinates::new(column as f32, line as f32)),
@@ -130,7 +118,8 @@ impl SimpleGameLayer for Layer {
                 }
             }
         }
-        world.push((Camera::new(768., 768., 10.), Transform::default()));
+        world.add_default_camera();
+
         resources.insert(Taquin::new());
     }
 }
@@ -139,14 +128,11 @@ fn main() {
     Scion::app_with_config(
         ScionConfigBuilder::new()
             .with_window_config(
-                WindowConfigBuilder::new()
-                    .with_resizable(false)
-                    .with_dimensions((768, 768))
-                    .get(),
+                WindowConfigBuilder::new().with_resizable(false).with_dimensions((768, 768)).get(),
             )
             .get(),
     )
     .with_system(taquin_system())
-    .with_game_layer(GameLayer::weak::<Layer>("Taquin"))
+    .with_scene::<MainScene>()
     .run();
 }
