@@ -2,7 +2,7 @@ use scion::{
     core::{
         components::maths::transform::Transform,
         resources::{
-            inputs::{inputs_controller::InputsController, keycode::KeyCode},
+            inputs::{inputs_controller::InputsController, types::KeyCode},
             time::Timers,
         },
     },
@@ -24,7 +24,7 @@ pub fn piece_rotation(
     world: &mut SubWorld,
     query: &mut Query<(Entity, &mut Bloc, &mut Transform)>,
 ) {
-    let rotation = inputs.keyboard().key_pressed(&KeyCode::Up);
+    let rotation = inputs.key_pressed(&KeyCode::Up);
     let movement_timer = timers
         .get_timer("action_reset_timer")
         .expect("Missing a mandatory timer in the game : action_reset_timer");
@@ -38,7 +38,7 @@ pub fn piece_rotation(
             let mut should_rotate_piece = true;
             for offset in rotation_offsets.iter() {
                 if x as f32 + offset.0 == 0.
-                    || x as f32 + offset.0 == (BOARD_WIDTH + 1) as f32
+                    || x as f32 + offset.0 >= (BOARD_WIDTH + 1) as f32
                     || y as f32 + offset.1 == (BOARD_HEIGHT + 1) as f32
                 {
                     should_rotate_piece = false;
