@@ -6,42 +6,26 @@ use legion::{
 };
 use log::info;
 use winit::{
+    event::{Event, WindowEvent},
     event_loop::{ControlFlow, EventLoop},
     window::{Window, WindowBuilder},
 };
 
+use crate::core::package::Package;
+use crate::core::resources::time::Time;
+use crate::core::scene::{Scene, SceneAction, SceneMachine};
+use crate::core::systems::collider_systems::colliders_cleaner_system;
+use crate::core::systems::InternalPackage;
 use crate::{
     config::scion_config::{ScionConfig, ScionConfigReader},
     core::{
-        components::{
-            material::Material,
-            ui::{
-                ui_image::UiImage,
-                ui_text::{UiText, UiTextImage},
-            },
-        },
-        event_handler::handle_event,
-        game_layer::{GameLayer, GameLayerController, GameLayerMachine, LayerAction},
-        legion_ext::PausableSystem,
-        resources::{
-            asset_manager::AssetManager,
-            events::{topic::TopicConfiguration, Events},
-            inputs::inputs_controller::InputsController,
-            time::{Time, Timers},
-            window::WindowDimensions,
-        },
+        event_handler::update_input_events,
+        legion_ext::{PausableSystem, ScionResourcesExtension},
+        resources::events::Events,
         state::GameState,
-        systems::{
-            animations_system::animation_executer_system,
-            asset_ref_resolver_system::{asset_ref_resolver_system, MaterialAssetResolverFn},
-            collider_systems::{colliders_cleaner_system, compute_collisions_system},
-            hierarchy_system::children_manager_system,
-            missing_ui_component_system::missing_ui_component_system,
-            parent_transform_system::{dirty_child_system, dirty_transform_system},
-            ui_text_system::ui_text_bitmap_update_system,
-        },
     },
     rendering::{renderer_state::RendererState, RendererType},
+    utils::debug_ecs::try_debug,
 };
 
 /// `Scion` is the entry point of any application made with Scion's lib.
@@ -51,7 +35,7 @@ pub struct Scion {
     world: World,
     resources: Resources,
     schedule: Schedule,
-    layer_machine: GameLayerMachine,
+    layer_machine: SceneMachine,
     window: Option<Window>,
     renderer: Option<RendererState>,
 }
@@ -80,99 +64,120 @@ impl Scion {
     /// The application will use the provided configuration.
     pub fn app_with_config(app_config: ScionConfig) -> ScionBuilder {
         crate::utils::logger::Logger::init_logging(app_config.logger_config.clone());
-        info!(
-            "Launching Scion application with the following configuration: {:?}",
-            app_config
-        );
+        info!("Launching Scion application with the following configuration: {:?}", app_config);
         ScionBuilder::new(app_config)
     }
 
     fn setup(&mut self) {
         self.initialize_internal_resources();
-        self.layer_machine.apply_layers_action(
-            LayerAction::Start,
+        self.layer_machine.apply_scene_action(
+            SceneAction::Start,
             &mut self.world,
             &mut self.resources,
         );
     }
 
     fn initialize_internal_resources(&mut self) {
-        let inner_size = self
-            .window
-            .as_ref()
-            .expect("No window found during setup")
-            .inner_size();
-        self.resources
-            .insert(WindowDimensions::new((inner_size.width, inner_size.height)));
-
-        let mut events = Events::default();
-        events
-            .create_topic("Inputs", TopicConfiguration::default())
-            .expect("Error while creating topic for inputs event");
-
-        self.resources.insert(Time::default());
-        self.resources.insert(events);
-        self.resources.insert(Timers::default());
-        self.resources.insert(AssetManager::default());
-        self.resources.insert(InputsController::default());
-        self.resources.insert(GameState::default());
-        self.resources.insert(GameLayerController::default());
+        let window = self.window.as_ref().expect("No window found during setup");
+        self.resources.insert(crate::core::resources::window::Window::new(
+            (window.inner_size().width, window.inner_size().height),
+            window.scale_factor(),
+        ));
     }
 
     fn run(mut self, event_loop: EventLoop<()>) {
         event_loop.run(move |event, _, control_flow| {
             *control_flow = ControlFlow::Poll;
-            handle_event(
-                event,
-                control_flow,
-                self.window
-                    .as_mut()
-                    .expect("A window is mandatory to run this game !"),
-                self.renderer
-                    .as_mut()
-                    .expect("A renderer is mandatory to run this game !"),
-                &mut self.world,
-                &mut self.resources,
-                &self.config,
-            );
-            self.next_frame();
-            self.layer_machine.apply_layers_action(
-                LayerAction::EndFrame,
-                &mut self.world,
-                &mut self.resources,
-            );
+
+            match event {
+                Event::WindowEvent { ref event, window_id }
+                    if window_id == self.window.as_mut().unwrap().id() =>
+                {
+                    match event {
+                        WindowEvent::CloseRequested => *control_flow = ControlFlow::Exit,
+                        WindowEvent::Resized(physical_size) => {
+                            self.resources
+                                .window()
+                                .set_dimensions(physical_size.width, physical_size.height);
+                            self.renderer.as_mut().unwrap().resize(
+                                *physical_size,
+                                self.window.as_ref().expect("Missing window").scale_factor(),
+                            );
+                        }
+                        WindowEvent::ScaleFactorChanged { new_inner_size, .. } => {
+                            self.renderer.as_mut().unwrap().resize(
+                                **new_inner_size,
+                                self.window.as_ref().expect("Missing window").scale_factor(),
+                            );
+                        }
+                        WindowEvent::CursorMoved { device_id: _, position, .. } => {
+                            let dpi_factor = self
+                                .window
+                                .as_mut()
+                                .unwrap()
+                                .current_monitor()
+                                .expect("Missing the monitor")
+                                .scale_factor();
+                            self.resources.inputs().set_mouse_position(
+                                position.x / dpi_factor,
+                                position.y / dpi_factor,
+                            );
+                        }
+                        _ => {}
+                    }
+
+                    update_input_events(event, &mut self.resources);
+                }
+                Event::MainEventsCleared => {
+                    self.next_frame();
+                    self.layer_machine.apply_scene_action(
+                        SceneAction::EndFrame,
+                        &mut self.world,
+                        &mut self.resources,
+                    );
+                    self.window.as_mut().unwrap().request_redraw();
+                }
+                Event::RedrawRequested(_) => {
+                    self.renderer.as_mut().unwrap().update(&mut self.world, &mut self.resources);
+                    match self.renderer.as_mut().unwrap().render(&mut self.world, &self.config) {
+                        Ok(_) => {}
+                        Err(e) => log::error!("{:?}", e),
+                    }
+                }
+                _ => (),
+            }
         });
     }
 
     fn next_frame(&mut self) {
+        try_debug(&mut self.world, &mut self.resources);
         let frame_duration = self
             .resources
             .get_mut::<Time>()
             .expect("Time is an internal resource and can't be missing")
             .frame();
-        self.resources
-            .get_mut::<Timers>()
-            .expect("Missing mandatory ressource : Timers")
-            .add_delta_duration(frame_duration);
-        self.layer_machine.apply_layers_action(
-            LayerAction::Update,
+        self.resources.timers().add_delta_duration(frame_duration);
+        self.layer_machine.apply_scene_action(
+            SceneAction::Update,
             &mut self.world,
             &mut self.resources,
         );
         self.schedule.execute(&mut self.world, &mut self.resources);
-        self.layer_machine.apply_layers_action(
-            LayerAction::LateUpdate,
+        self.layer_machine.apply_scene_action(
+            SceneAction::LateUpdate,
             &mut self.world,
             &mut self.resources,
         );
-        self.resources
-            .get_mut::<InputsController>()
-            .expect("Missing mandatory ressource : InputsController")
-            .reset_inputs();
-        self.resources
-            .get_mut::<Events>()
-            .expect("Missing mandatory ressource : Events")
-            .cleanup();
+        {
+            let mut window = self.resources.window();
+            if let Some(icon) = window.new_cursor() {
+                let w = self.window.as_mut().expect("A window is mandatory to run this game !");
+                w.set_cursor_icon(*icon);
+                window.reset_new_cursor();
+            }
+        }
+        self.resources.inputs().reset_inputs();
+        self.resources.get_mut::<Events>().expect("Missing mandatory ressource : Events").cleanup();
     }
 }
 
@@ -183,19 +188,22 @@ pub struct ScionBuilder {
     config: ScionConfig,
     schedule_builder: Builder,
     renderer: RendererType,
-    game_layers: Vec<Box<GameLayer>>,
+    scene: Option<Box<dyn Scene>>,
+    world: World,
+    resource: Resources,
 }
 
 impl ScionBuilder {
     fn new(config: ScionConfig) -> Self {
-        let mut builder = Self {
+        let builder = Self {
             config,
             schedule_builder: Default::default(),
             renderer: Default::default(),
-            game_layers: Default::default(),
+            scene: Default::default(),
+            world: Default::default(),
+            resource: Default::default(),
         };
-        builder.init_schedule_with_internal_systems();
-        builder
+        builder.with_package(InternalPackage)
     }
 
     /// Add a [legion](https://docs.rs/legion/latest/legion/) system to the scheduler.
@@ -231,27 +239,35 @@ impl ScionBuilder {
             .chain(std::iter::once(ResourceTypeId::of::<GameState>()))
             .collect::<Vec<_>>();
         let boxed_condition = Box::new(condition);
-        let pausable_system = PausableSystem {
-            system,
-            decider: boxed_condition,
-            resource_reads,
-        };
+        let pausable_system = PausableSystem { system, decider: boxed_condition, resource_reads };
         self.schedule_builder.add_system(pausable_system);
         self
     }
 
+    /// Specify which render type you want to use. Note that by default if not set, `Scion` will use [`crate::rendering::RendererType::Scion2D`].
+    pub fn with_flush(mut self) -> Self {
+        self.schedule_builder.flush();
+        self
+    }
+
     /// Specify which render type you want to use. Note that by default if not set, `Scion` will use [`crate::rendering::RendererType::Scion2D`].
     pub fn with_renderer(mut self, renderer_type: RendererType) -> Self {
         self.renderer = renderer_type;
         self
     }
 
-    /// Add a game layer to the pile. Not that the order in which you add them is important if you use the concept of Strong layers.
-    pub fn with_game_layer(mut self, game_layer: Box<GameLayer>) -> Self {
-        self.game_layers.push(game_layer);
+    /// Add a normal game layer to the pile. Every layer added before in the pile will be called
+    pub fn with_scene<T: Scene + Default + 'static>(mut self) -> Self {
+        self.scene = Some(Box::new(T::default()));
         self
     }
 
+    ///
+    pub fn with_package<P: Package>(mut self, package: P) -> Self {
+        package.prepare(&mut self.world, &mut self.resource);
+        package.load(self)
+    }
+
     /// Builds, setups and runs the Scion application, must be called at the end of the building process.
     pub fn run(mut self) {
         let event_loop = EventLoop::new();
@@ -260,7 +276,7 @@ impl ScionBuilder {
             .window_config
             .clone()
             .expect("The window configuration has not been found")
-            .into();
+            .into(&self.config);
         let window = window_builder
             .build(&event_loop)
             .expect("An error occured while building the main game window");
@@ -274,12 +290,10 @@ impl ScionBuilder {
 
         let mut scion = Scion {
             config: self.config,
-            world: Default::default(),
-            resources: Default::default(),
+            world: self.world,
+            resources: self.resource,
             schedule: self.schedule_builder.build(),
-            layer_machine: GameLayerMachine {
-                game_layers: self.game_layers,
-            },
+            layer_machine: SceneMachine { current_scene: self.scene },
             window: Some(window),
             renderer: Some(renderer_state),
         };
@@ -288,33 +302,7 @@ impl ScionBuilder {
         scion.run(event_loop);
     }
 
-    fn init_schedule_with_internal_systems(&mut self) {
-        self.schedule_builder
-            .add_system(ui_text_bitmap_update_system());
-        self.schedule_builder.flush();
-        self.schedule_builder.add_system(children_manager_system());
-        self.schedule_builder
-            .add_system(missing_ui_component_system::<UiImage>());
-        self.schedule_builder
-            .add_system(missing_ui_component_system::<UiTextImage>());
-        self.schedule_builder
-            .add_system(missing_ui_component_system::<UiText>());
-        self.schedule_builder
-            .add_system(asset_ref_resolver_system::<Material, MaterialAssetResolverFn>());
-        self.schedule_builder
-            .add_system(animation_executer_system());
-        self.schedule_builder.flush();
-        self.schedule_builder.add_system(dirty_child_system());
-        self.schedule_builder.flush();
-        self.schedule_builder.add_system(dirty_transform_system());
-
-        self.schedule_builder
-            .add_system(compute_collisions_system());
-        self.schedule_builder.flush();
-    }
-
     fn add_late_internal_systems_to_schedule(&mut self) {
-        self.schedule_builder.flush();
-        self.schedule_builder.add_system(colliders_cleaner_system());
+        self.schedule_builder.flush().add_system(colliders_cleaner_system());
     }
 }
