@@ -6,14 +6,12 @@ use winit::{
     window::{WindowAttributes, WindowBuilder},
 };
 
-use crate::core::components::color::Color;
+use crate::{config::scion_config::ScionConfig, core::components::color::Color};
 
 /// Main configuration for the game window
 /// Please use [`WindowConfigBuilder`] if you want to build if from code.
 #[derive(Debug, Serialize, Deserialize, Clone)]
 pub struct WindowConfig {
-    /// Window title
-    pub(crate) title: String,
     /// Enables fullscreen mode
     pub(crate) fullscreen: bool,
     /// Default window width and height in pixels.
@@ -43,10 +41,9 @@ pub struct WindowConfig {
 impl Default for WindowConfig {
     fn default() -> Self {
         Self {
-            title: "Default Scion game".to_string(),
             fullscreen: false,
             dimensions: Some((1024, 768)),
-            min_dimensions: Some((500, 480)),
+            min_dimensions: Some((384, 336)),
             max_dimensions: None,
             visibility: true,
             icon: None,
@@ -60,43 +57,12 @@ impl Default for WindowConfig {
     }
 }
 
-pub struct WindowConfigBuilder {
-    config: WindowConfig,
-}
-
-impl WindowConfigBuilder {
-    pub fn new() -> Self {
-        Self {
-            config: Default::default(),
-        }
-    }
-
-    pub fn with_dimensions(mut self, dimensions: (u32, u32)) -> Self {
-        self.config.dimensions = Some(dimensions);
-        self
-    }
-
-    pub fn with_resizable(mut self, resizable: bool) -> Self {
-        self.config.resizable = resizable;
-        self
-    }
-
-    pub fn with_default_background_color(mut self, color: Option<Color>) -> Self {
-        self.config.default_background_color = color;
-        self
-    }
-
-    pub fn get(self) -> WindowConfig {
-        self.config
-    }
-}
-
-impl Into<WindowBuilder> for WindowConfig {
-    fn into(self) -> WindowBuilder {
+impl WindowConfig {
+    pub(crate) fn into(self, scion_config: &ScionConfig) -> WindowBuilder {
         let mut builder = WindowBuilder::new();
 
         builder.window = WindowAttributes {
-            title: self.title.clone(),
+            title: scion_config.app_name.clone(),
             fullscreen: None,
             inner_size: self.dimensions.map(|d| d.into()).map(Size::Logical),
             min_inner_size: self.min_dimensions.map(|d| d.into()).map(Size::Logical),
@@ -113,3 +79,38 @@ impl Into<WindowBuilder> for WindowConfig {
         builder
     }
 }
+
+/// `WindowConfigBuilder` is a convenience builder to create a `WindowConfig` from code.
+pub struct WindowConfigBuilder {
+    config: WindowConfig,
+}
+
+impl WindowConfigBuilder {
+    /// Create a new `WindowConfigBuilder` builder
+    pub fn new() -> Self {
+        Self { config: Default::default() }
+    }
+
+    /// Dimension of the window
+    pub fn with_dimensions(mut self, dimensions: (u32, u32)) -> Self {
+        self.config.dimensions = Some(dimensions);
+        self
+    }
+
+    /// Whether or not the window should be resizable
+    pub fn with_resizable(mut self, resizable: bool) -> Self {
+        self.config.resizable = resizable;
+        self
+    }
+
+    /// When rendering to the window, which color to use as default
+    pub fn with_default_background_color(mut self, color: Option<Color>) -> Self {
+        self.config.default_background_color = color;
+        self
+    }
+
+    /// Retrieves the configuration built
+    pub fn get(self) -> WindowConfig {
+        self.config
+    }
+}
