@@ -1,6 +1,6 @@
 use serde::{Deserialize, Serialize};
 
-use crate::rendering::bidimensional::gl_representations::GlColor;
+use crate::rendering::gl_representations::GlColor;
 
 /// A struct that represents colors for rendering.
 #[derive(Clone, Debug, Serialize, Deserialize)]
@@ -18,10 +18,7 @@ pub struct Color {
 impl Color {
     /// Creates a new color using RGBA values
     pub fn new(r: u8, g: u8, b: u8, a: f32) -> Self {
-        assert!(
-            a <= 1. && a >= 0.,
-            "Alpha value must be between 0.0 and 1.0"
-        );
+        assert!(a <= 1. && a >= 0., "Alpha value must be between 0.0 and 1.0");
         Self { r, g, b, a }
     }
 
@@ -30,6 +27,7 @@ impl Color {
         Color::new(r, g, b, 1.0)
     }
 
+    /// Replaces the current color with the given one
     pub fn replace(&mut self, color: Color) {
         self.r = color.r;
         self.g = color.g;
@@ -37,18 +35,22 @@ impl Color {
         self.a = color.a;
     }
 
+    /// Red value
     pub fn red(&self) -> u8 {
         self.r
     }
 
+    /// Green value
     pub fn green(&self) -> u8 {
         self.g
     }
 
+    /// Blue value
     pub fn blue(&self) -> u8 {
         self.b
     }
 
+    /// Alpha value
     pub fn alpha(&self) -> f32 {
         self.a
     }
