@@ -1,43 +1,12 @@
-/// Convenience struct used in all `Scion` to specify any 2D position.
+use crate::{core::components::maths::coordinates::Coordinates, utils::maths::Vector};
+
+/// represents the bounds for a Transoform with min and max values
 #[derive(Default, Debug, Copy, Clone)]
-pub struct Coordinates {
-    x: f32,
-    y: f32,
-    layer: usize,
-}
-
-impl Coordinates {
-    pub fn new(x: f32, y: f32) -> Self {
-        Self { x, y, layer: 0 }
-    }
-
-    pub fn new_with_layer(x: f32, y: f32, layer: usize) -> Self {
-        Self { x, y, layer }
-    }
-
-    pub fn x(&self) -> f32 {
-        self.x
-    }
-
-    pub fn y(&self) -> f32 {
-        self.y
-    }
-
-    pub fn layer(&self) -> usize {
-        self.layer
-    }
-
-    pub fn set_x(&mut self, x: f32) {
-        self.x = x
-    }
-
-    pub fn set_y(&mut self, y: f32) {
-        self.y = y;
-    }
-
-    pub fn set_layer(&mut self, layer: usize) {
-        self.layer = layer;
-    }
+struct Bounds {
+    pub(crate) min_x: Option<f32>,
+    pub(crate) max_x: Option<f32>,
+    pub(crate) min_y: Option<f32>,
+    pub(crate) max_y: Option<f32>,
 }
 
 /// Component used by the renderer to know where and how to represent an object.
@@ -50,10 +19,8 @@ pub struct Transform {
     pub(crate) angle: f32,
     pub(crate) dirty: bool,
     pub(crate) dirty_child: bool,
-    pub(crate) min_x: Option<f32>,
-    pub(crate) max_x: Option<f32>,
-    pub(crate) min_y: Option<f32>,
-    pub(crate) max_y: Option<f32>,
+    pub(crate) use_screen_as_origin: bool,
+    bounds: Bounds,
 }
 
 impl Default for Transform {
@@ -65,10 +32,8 @@ impl Default for Transform {
             angle: 0.0,
             dirty: false,
             dirty_child: true,
-            min_x: None,
-            max_x: None,
-            min_y: None,
-            max_y: None,
+            use_screen_as_origin: false,
+            bounds: Default::default(),
         }
     }
 }
@@ -83,13 +48,21 @@ impl Transform {
             angle,
             dirty: false,
             dirty_child: true,
-            min_x: None,
-            max_x: None,
-            min_y: None,
-            max_y: None,
+            use_screen_as_origin: false,
+            bounds: Default::default(),
         }
     }
 
+    /// Creates a transform from x and y values. Will use z value 0, scale 1. and default angle.
+    pub fn from_xy(x: f32, y: f32) -> Self {
+        Self::new(Coordinates::new(x, y), 1., 0.)
+    }
+
+    /// Creates a transform from x, y and z values. Will use scale 1. and default angle.
+    pub fn from_xyz(x: f32, y: f32, z: usize) -> Self {
+        Self::new(Coordinates::new_with_z(x, y, z), 1., 0.)
+    }
+
     /// Append a translation to this transform's position
     pub fn append_translation(&mut self, x: f32, y: f32) {
         self.local_translation.x += x;
@@ -100,6 +73,11 @@ impl Transform {
         self.handle_bounds();
     }
 
+    /// Append a translation to this transform's position
+    pub fn append_vector(&mut self, vector: Vector) {
+        self.append_translation(vector.x, vector.y);
+    }
+
     /// Appends the x val to the translation's x value
     pub fn append_x(&mut self, x: f32) {
         self.local_translation.x += x;
@@ -144,32 +122,37 @@ impl Transform {
         self.scale = scale
     }
 
-    /// Change the layer value in the coordinates.
-    pub fn set_layer(&mut self, layer: usize) {
-        self.local_translation.layer = layer
+    /// Change the z value in the coordinates.
+    pub fn set_z(&mut self, z: usize) {
+        self.local_translation.z = z
     }
 
     /// Configure the minimum global x position for this transform to be min_x
     pub fn set_min_x(&mut self, min_x: Option<f32>) {
-        self.min_x = min_x;
+        self.bounds.min_x = min_x;
         self.handle_bounds();
     }
 
     /// Configure the maximum global x position for this transform to be max_x
     pub fn set_max_x(&mut self, max_x: Option<f32>) {
-        self.max_x = max_x;
+        self.bounds.max_x = max_x;
         self.handle_bounds();
     }
 
     /// Configure the minimum global y position for this transform to be min_x
     pub fn set_min_y(&mut self, min_y: Option<f32>) {
-        self.min_y = min_y;
+        self.bounds.min_y = min_y;
         self.handle_bounds();
     }
 
     /// Configure the maximum global y position for this transform to be max_x
     pub fn set_max_y(&mut self, max_y: Option<f32>) {
-        self.max_y = max_y;
+        self.bounds.max_y = max_y;
+        self.handle_bounds();
+    }
+
+    pub fn set_use_screen_as_origin(&mut self, new_value: bool) {
+        self.use_screen_as_origin = new_value;
         self.handle_bounds();
     }
 
@@ -181,10 +164,10 @@ impl Transform {
         min_y: Option<f32>,
         max_y: Option<f32>,
     ) {
-        self.min_x = min_x;
-        self.max_x = max_x;
-        self.min_y = min_y;
-        self.max_y = max_y;
+        self.bounds.min_x = min_x;
+        self.bounds.max_x = max_x;
+        self.bounds.min_y = min_y;
+        self.bounds.max_y = max_y;
         self.handle_bounds();
     }
 
@@ -193,32 +176,32 @@ impl Transform {
         let mut new_global = parent_translation.clone();
         new_global.x += self.local_translation.x;
         new_global.y += self.local_translation.y;
-        new_global.layer = self.local_translation.layer;
+        new_global.z = self.local_translation.z;
         self.global_translation = new_global;
         self.dirty = true;
         self.handle_bounds();
     }
 
     fn handle_bounds(&mut self) {
-        if let Some(min_x) = self.min_x {
+        if let Some(min_x) = self.bounds.min_x {
             if self.global_translation.x < min_x {
                 self.global_translation.set_x(min_x);
             }
         }
 
-        if let Some(max_x) = self.max_x {
+        if let Some(max_x) = self.bounds.max_x {
             if self.global_translation.x > max_x {
                 self.global_translation.set_x(max_x);
             }
         }
 
-        if let Some(min_y) = self.min_y {
+        if let Some(min_y) = self.bounds.min_y {
             if self.global_translation.y < min_y {
                 self.global_translation.set_y(min_y);
             }
         }
 
-        if let Some(max_y) = self.max_y {
+        if let Some(max_y) = self.bounds.max_y {
             if self.global_translation.y > max_y {
                 self.global_translation.set_y(max_y);
             }
@@ -226,6 +209,48 @@ impl Transform {
     }
 }
 
+pub struct TransformBuilder {
+    transform: Transform,
+}
+
+impl TransformBuilder {
+    pub fn new() -> Self {
+        Self { transform: Transform::default() }
+    }
+
+    pub fn with_xy(mut self, x: f32, y: f32) -> Self {
+        let translation = Coordinates::new(x, y);
+        self.transform.local_translation = translation;
+        self.transform.global_translation = translation;
+        self
+    }
+    pub fn with_translation(mut self, x: f32, y: f32, z: usize) -> Self {
+        let translation = Coordinates::new_with_z(x, y, z);
+        self.transform.local_translation = translation;
+        self.transform.global_translation = translation;
+        self
+    }
+
+    pub fn with_scale(mut self, scale: f32) -> Self {
+        self.transform.scale = scale;
+        self
+    }
+
+    pub fn with_angle(mut self, angle: f32) -> Self {
+        self.transform.angle = angle;
+        self
+    }
+
+    pub fn with_screen_as_origin(mut self) -> Self {
+        self.transform.use_screen_as_origin = true;
+        self
+    }
+
+    pub fn build(self) -> Transform {
+        self.transform
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use crate::core::components::maths::transform::{Coordinates, Transform};
