@@ -9,3 +9,8 @@ pub mod maths;
 pub mod shapes;
 pub mod tiles;
 pub mod ui;
+
+/// Struct to add to any entity to 'hide' it during rendering
+pub struct Hide;
+
+pub(crate) struct HidePropagated;
