@@ -1,3 +1,5 @@
+pub mod line;
+pub mod polygon;
 pub mod rectangle;
 pub mod square;
 pub mod triangle;
