@@ -1,10 +1,13 @@
 use std::ops::Range;
 
-use wgpu::util::BufferInitDescriptor;
+use wgpu::{util::BufferInitDescriptor, PrimitiveTopology};
 
 use crate::{
-    core::components::{material::Material, maths::transform::Coordinates},
-    rendering::bidimensional::{gl_representations::TexturedGlVertex, scion2d::Renderable2D},
+    core::components::{
+        material::Material,
+        maths::{coordinates::Coordinates, Pivot},
+    },
+    rendering::{gl_representations::TexturedGlVertex, Renderable2D},
 };
 
 const INDICES: &[u16] = &[0, 1, 3, 3, 1, 2];
@@ -14,11 +17,28 @@ pub struct Square {
     pub vertices: [Coordinates; 4],
     pub uvs: Option<[Coordinates; 4]>,
     contents: [TexturedGlVertex; 4],
+    length: f32,
 }
 
 impl Square {
+    /// Creates a new square using `length`.
+    /// When rendering using a texture, you can customize uvs map using `uvs`. By default it will
+    /// use 0 to 1 uvs
     pub fn new(length: f32, uvs: Option<[Coordinates; 4]>) -> Self {
-        let a = Coordinates::new(0., 0.);
+        Square::new_with_offset(length, uvs, 0.)
+    }
+
+    /// Sets the pivot point of the square and returns it
+    pub fn pivot(self, pivot: Pivot) -> Self {
+        let offset = match pivot {
+            Pivot::TopLeft => 0.,
+            Pivot::Center => self.length / 2.,
+        };
+        Square::new_with_offset(self.length, self.uvs, offset)
+    }
+
+    fn new_with_offset(length: f32, uvs: Option<[Coordinates; 4]>, offset: f32) -> Self {
+        let a = Coordinates::new(0. - offset, 0. - offset);
         let b = Coordinates::new(a.x(), a.y() + length);
         let c = Coordinates::new(a.x() + length, a.y() + length);
         let d = Coordinates::new(a.x() + length, a.y());
@@ -29,11 +49,7 @@ impl Square {
             TexturedGlVertex::from((&c, &uvs_ref[2])),
             TexturedGlVertex::from((&d, &uvs_ref[3])),
         ];
-        Self {
-            vertices: [a, b, c, d],
-            uvs,
-            contents,
-        }
+        Self { vertices: [a, b, c, d], uvs, contents, length }
     }
 }
 
@@ -51,7 +67,7 @@ impl Renderable2D for Square {
         wgpu::util::BufferInitDescriptor {
             label: Some("Square Vertex Buffer"),
             contents: bytemuck::cast_slice(&self.contents),
-            usage: wgpu::BufferUsage::VERTEX,
+            usage: wgpu::BufferUsages::VERTEX,
         }
     }
 
@@ -59,7 +75,7 @@ impl Renderable2D for Square {
         wgpu::util::BufferInitDescriptor {
             label: Some("Square Index Buffer"),
             contents: bytemuck::cast_slice(&INDICES),
-            usage: wgpu::BufferUsage::INDEX,
+            usage: wgpu::BufferUsages::INDEX,
         }
     }
 
@@ -67,6 +83,10 @@ impl Renderable2D for Square {
         0..INDICES.len() as u32
     }
 
+    fn topology() -> PrimitiveTopology {
+        wgpu::PrimitiveTopology::TriangleList
+    }
+
     fn dirty(&self) -> bool {
         false
     }
