@@ -1,16 +1,13 @@
 use std::ops::Range;
 
-use wgpu::util::BufferInitDescriptor;
+use wgpu::{util::BufferInitDescriptor, PrimitiveTopology};
 
 use crate::{
-    core::components::{material::Material, maths::transform::Coordinates},
-    rendering::bidimensional::{
-        gl_representations::TexturedGlVertex,
-        scion2d::{Renderable2D, RenderableUi},
-    },
+    core::components::{material::Material, maths::coordinates::Coordinates},
+    rendering::{gl_representations::TexturedGlVertex, Renderable2D, RenderableUi},
 };
 
-/// Renderable 2D Square.
+/// Renderable 2D UIImage
 #[derive(Debug)]
 pub struct UiImage {
     image_path: String,
@@ -20,6 +17,7 @@ pub struct UiImage {
 const INDICES: &[u16] = &[0, 1, 3, 3, 1, 2];
 
 impl UiImage {
+    /// Creates a ui_image with `width` and `height` using image at `image_path`
     pub fn new(width: f32, height: f32, image_path: String) -> Self {
         let uvs = [
             Coordinates::new(0., 0.),
@@ -30,6 +28,8 @@ impl UiImage {
         UiImage::new_with_uv_map(width, height, image_path, uvs)
     }
 
+    /// Creates a ui_image with `width` and `height` using image at `image_path`
+    /// and customising uv_map
     pub fn new_with_uv_map(
         width: f32,
         height: f32,
@@ -47,27 +47,24 @@ impl UiImage {
             TexturedGlVertex::from((&c, &uvs[2])),
             TexturedGlVertex::from((&d, &uvs[3])),
         ];
-        Self {
-            image_path,
-            contents,
-        }
+        Self { image_path, contents }
     }
 }
 
 impl Renderable2D for UiImage {
     fn vertex_buffer_descriptor(&mut self, _material: Option<&Material>) -> BufferInitDescriptor {
         wgpu::util::BufferInitDescriptor {
-            label: Some("Square Vertex Buffer"),
+            label: Some("UI Image vertex buffer"),
             contents: bytemuck::cast_slice(&self.contents),
-            usage: wgpu::BufferUsage::VERTEX,
+            usage: wgpu::BufferUsages::VERTEX,
         }
     }
 
     fn indexes_buffer_descriptor(&self) -> BufferInitDescriptor {
         wgpu::util::BufferInitDescriptor {
-            label: Some("Square Index Buffer"),
+            label: Some("UI Image index buffer"),
             contents: bytemuck::cast_slice(&INDICES),
-            usage: wgpu::BufferUsage::INDEX,
+            usage: wgpu::BufferUsages::INDEX,
         }
     }
 
@@ -75,6 +72,10 @@ impl Renderable2D for UiImage {
         0..INDICES.len() as u32
     }
 
+    fn topology() -> PrimitiveTopology {
+        wgpu::PrimitiveTopology::TriangleList
+    }
+
     fn dirty(&self) -> bool {
         false
     }
