@@ -1,7 +1,9 @@
+pub(crate) mod audio_controller;
 pub mod components;
 pub(crate) mod event_handler;
-pub mod game_layer;
 pub mod legion_ext;
+pub mod package;
 pub mod resources;
+pub mod scene;
 pub mod state;
 pub mod systems;
