@@ -26,10 +26,19 @@ impl AssetManager {
 
     pub fn register_tileset(&mut self, tileset: Tileset) -> AssetRef<Material> {
         let next_ref = AssetRef(self.materials.keys().count(), PhantomData::default());
-        self.materials
-            .insert(next_ref.0, Material::Tileset(tileset));
+        self.materials.insert(next_ref.0, Material::Tileset(tileset));
         next_ref
     }
+
+    pub fn retrieve_tileset(&self, asset_ref: &AssetRef<Material>) -> Option<&Tileset> {
+        match self.materials.get(&asset_ref.0) {
+            None => None,
+            Some(material) => match material {
+                Material::Tileset(tileset) => Some(tileset),
+                _ => None,
+            },
+        }
+    }
 }
 
 #[derive(Clone)]
@@ -43,6 +52,8 @@ mod tests {
         components::{color::Color, material::Material, tiles::tileset::Tileset},
         resources::asset_manager::AssetManager,
     };
+    
+    
 
     #[test]
     fn register_material_test() {
