@@ -7,6 +7,8 @@ use crate::core::components::maths::{
     transform::Transform,
 };
 
+/// System responsible of detecting when a transform's global coords should be computed again
+/// based on the fact that the transform is flagged as dirty_child (IE when it's added to a parent)
 #[system]
 pub(crate) fn dirty_child(
     world: &mut SubWorld,
@@ -17,6 +19,7 @@ pub(crate) fn dirty_child(
         Option<&Children>,
     )>,
 ) {
+    // GET all the childs that are 'dirty childs'
     let mut parent_to_check = Vec::new();
     query_transform_with_parent.for_each_mut(world, |(child_entity, transform, parent, _child)| {
         if transform.dirty_child {
@@ -28,12 +31,10 @@ pub(crate) fn dirty_child(
         }
     });
 
+    // GET all the parents that needs to be checked
     let mut parents_transform = HashMap::new();
     for (_, parent) in parent_to_check.iter() {
-        if let Ok(parent_transform) = world
-            .entry_ref(*parent)
-            .unwrap()
-            .get_component::<Transform>()
+        if let Ok(parent_transform) = world.entry_ref(*parent).unwrap().get_component::<Transform>()
         {
             parents_transform.insert(*parent, parent_transform.clone());
         }
@@ -51,12 +52,15 @@ pub(crate) fn dirty_child(
                 .expect("Missing Transform component previously found on this entity");
             if parents_transform.contains_key(&parent) {
                 let parent_transform = parents_transform.get(&parent).unwrap();
+                // If the parent of the current entity is not a dirty child, then we can compute the current
+                // transform
                 if !parent_transform.dirty_child {
                     child_transform.dirty_child = false;
                     child_transform
                         .compute_global_from_parent(parent_transform.global_translation());
                     parents_transform.insert(child, child_transform.clone());
                 } else {
+                    // Else we need to check the parent first, in the next iteration
                     parent_to_check.push((child, parent));
                 }
             } else {
@@ -67,6 +71,8 @@ pub(crate) fn dirty_child(
     }
 }
 
+/// System responsible of detecting when a child transform should be computed again based on any parent
+/// transform modification
 #[system]
 pub(crate) fn dirty_transform(
     world: &mut SubWorld,
@@ -104,10 +110,7 @@ mod tests {
     use legion::{IntoQuery, Resources, Schedule, World};
 
     use super::*;
-    use crate::core::{
-        components::maths::{hierarchy::Parent, transform::Coordinates},
-        systems::hierarchy_system::*,
-    };
+    use crate::core::{components::maths::hierarchy::Parent, systems::hierarchy_system::*};
 
     #[test]
     fn dirty_parent_transform_test() {
@@ -121,9 +124,9 @@ mod tests {
             .add_system(dirty_transform_system())
             .build();
 
-        let parent_transform = Transform::new(Coordinates::new(1., 1.), 1., 0.);
-        let child_transform = Transform::new(Coordinates::new(1., 1.), 1., 0.);
-        let child_of_child_transform = Transform::new(Coordinates::new(1., 1.), 1., 0.);
+        let parent_transform = Transform::from_xy(1., 1.);
+        let child_transform = Transform::from_xy(1., 1.);
+        let child_of_child_transform = Transform::from_xy(1., 1.);
         let parent = world.push((parent_transform,));
         let child = world.push((child_transform, Parent(parent)));
         let child_of_child = world.push((child_of_child_transform, Parent(child)));
