@@ -1,22 +1,30 @@
 //! Everything that is relative to rendering to the window (Like renderable components, camera, transforms..)
+use std::ops::Range;
+
 use legion::{Resources, World};
-use wgpu::{CommandEncoder, Device, Queue, SwapChainDescriptor, SwapChainTexture};
+use scion2d::Scion2D;
+use wgpu::{
+    util::BufferInitDescriptor, CommandEncoder, Device, Queue, SurfaceConfiguration, TextureView,
+};
 
-use crate::{config::scion_config::ScionConfig, rendering::bidimensional::scion2d::Scion2D};
+use crate::{config::scion_config::ScionConfig, core::components::material::Material};
 
-pub mod bidimensional;
+pub(crate) mod gl_representations;
 pub(crate) mod renderer_state;
+pub(crate) mod scion2d;
 pub(crate) mod shaders;
 
 /// Trait to implement in order to create a renderer to use in a `Scion` application
 pub trait ScionRenderer {
+    fn start(&mut self, device: &Device, surface_config: &SurfaceConfiguration);
+
     /// Will be called first, before render, each time the window request redraw.
     fn update(
         &mut self,
         world: &mut World,
         resources: &mut Resources,
         device: &Device,
-        sc_desc: &SwapChainDescriptor,
+        surface_config: &SurfaceConfiguration,
         queue: &mut Queue,
     );
 
@@ -25,7 +33,7 @@ pub trait ScionRenderer {
         &mut self,
         world: &mut World,
         config: &ScionConfig,
-        frame: &SwapChainTexture,
+        texture_view: &TextureView,
         encoder: &mut CommandEncoder,
     );
 }
@@ -52,3 +60,18 @@ impl RendererType {
         }
     }
 }
+
+pub(crate) trait Renderable2D {
+    fn vertex_buffer_descriptor(&mut self, material: Option<&Material>) -> BufferInitDescriptor;
+    fn indexes_buffer_descriptor(&self) -> BufferInitDescriptor;
+    fn range(&self) -> Range<u32>;
+    fn topology() -> wgpu::PrimitiveTopology;
+    fn dirty(&self) -> bool;
+    fn set_dirty(&mut self, is_dirty: bool);
+}
+
+pub(crate) trait RenderableUi: Renderable2D {
+    fn get_texture_path(&self) -> Option<String> {
+        None
+    }
+}
